@@ -10,7 +10,5 @@ MEDIA_URL = 'http://media.my_project.com/'
 MEDIA_ROOT = '/media'
 
 ## Thumbor ##
-THUMBOR_SERVER = 'http://ro.thumbor-server'
-THUMBOR_WRITABLE_SERVER = 'http://rw.thumbor-server'
-#THUMBOR_MEDIA_URL = 'http://localhost:8000/media'
+THUMBOR_RW_SERVER = 'http://rw.thumbor-server'
 THUMBOR_SECURITY_KEY = 'MY_SECURE_KEY'
